# pygrafical (beta)

**pygrafical** is a Windows API-based graphics library written in C++ designed to optimize graphical functions 

## Installation
to install the library, you can use the following command
```bash
pip install pygrafical
```
## Functions
there are many functions in this library
## What's new?
added a feature to get new paths to hooks